AuthMiddleware class
Authentication middleware
Constructors
- AuthMiddleware({String? jwtSecret})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- jwtSecret → String?
-
final
- middleware → Middleware
-
Middleware function for request handling
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited