AuthResult class

Authentication result

Constructors

AuthResult({required bool success, String? message, Map<String, dynamic>? user, Session? session, String? token, Map<String, dynamic>? data})
AuthResult.error(String error)
factory
AuthResult.success({String? message, Map<String, dynamic>? user, Session? session, String? token, Map<String, dynamic>? data})
factory

Properties

data Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session Session?
final
success bool
final
token String?
final
user Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited