Guard class abstract

Base interface for authentication guards

Constructors

Guard()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

check(Request request) Future<bool>
Check if request is authenticated
middleware() → Middleware
Create guard middleware
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
user(Request request) Map<String, dynamic>?
Get user data from request

Operators

operator ==(Object other) bool
The equality operator.
inherited