JWT class

JWT token

Constructors

JWT({required String token, required Map<String, dynamic> payload, String? signature, DateTime? issuedAt, DateTime? expiresAt})

Properties

expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
issuedAt DateTime?
final
payload Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String?
final
token String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(Map<String, dynamic> payload, {String? secret, Duration? expiresIn}) JWT
Create a JWT token
verify(String token, {String? secret}) JWT?
Verify a JWT token