ServiceProvider class abstract

Base class for service providers Service providers are used to register services with the container

Constructors

ServiceProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

boot(DIContainer container) Future<void>
Bootstrap the provider (called after registration)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(DIContainer container) → void
Register services with the container
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited