SimpleModule class

A simple module implementation

Inheritance
Available extensions

Constructors

SimpleModule(void _registerFn(DIContainer))

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
providers() List<ServiceProvider>
Get all service providers from this module
inherited
register(DIContainer container) → void
Register services provided by this module
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited