DatabaseManager class

Database connection manager for Dartian ORM

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

inMemoryDatabase() QueryDatabase
Create an in-memory database
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sqliteDatabase(String dbName, {String? directory}) QueryDatabase
Create a SQLite database dbName - Name of the database file (without extension) directory - Directory to store the database file (defaults to current directory)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DatabaseManager
no setter