DriftMigration class abstract

Drift-based migration interface

Provides a clean API for database migrations using Drift. Use this instead of the legacy Migration class for new projects.

Constructors

DriftMigration()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
Migration version number
no setter

Methods

down(Migrator m, QueryExecutor executor) Future<void>
Reverse the migration (optional)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
up(Migrator m, QueryExecutor executor) Future<void>
Run the migration

Operators

operator ==(Object other) bool
The equality operator.
inherited