QueryBuilder class

Query builder for building SQL queries in a fluent manner

Constructors

QueryBuilder(QueryDatabase _db, String _table)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() DeleteQuery
Delete from the table
insert(Map<String, dynamic> data) InsertQuery
Insert into the table
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(List<String> columns) SelectQuery
Select columns from the table
toString() String
A string representation of this object.
inherited
update(Map<String, dynamic> data) UpdateQuery
Update the table

Operators

operator ==(Object other) bool
The equality operator.
inherited