QueryDatabase class

Database class that wraps a sqlite3 database connection

Constructors

QueryDatabase(Database _database)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Close the database
execute(String sql, List args) int
Execute a command (INSERT, UPDATE, DELETE)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String sql, List args, {int? limit, int? offset}) List<Map<String, dynamic>>
Execute a query
querySingle<T>(String sql, List args) → T
Execute a query that returns a single value
tableExists(String tableName) bool
Check if a table exists
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited