Repository<T> class abstract

Base repository class for data access

Constructors

Repository(QueryDatabase _db)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count() int
Count all records
delete(dynamic id) → void
Delete a record
findAll() List<T>
Find all records
findById(dynamic id) → T?
Find a record by ID
insert(T record) → T
Insert a record
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(T record) → T
Update a record

Operators

operator ==(Object other) bool
The equality operator.
inherited