SelectQuery class

Constructors

SelectQuery(QueryDatabase _db, String _table, List<String> _columns)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get() List<Map<String, dynamic>>
Execute the query and return results
limit(int count) SelectQuery
Add LIMIT
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(int count) SelectQuery
Add OFFSET
orderBy(String column, {bool descending = false}) SelectQuery
Add ORDER BY clause
toString() String
A string representation of this object.
inherited
where(String condition, [List args = const []]) SelectQuery
Add WHERE condition

Operators

operator ==(Object other) bool
The equality operator.
inherited