UpdateQuery class

Constructors

UpdateQuery(QueryDatabase _db, String _table, Map<String, dynamic> _data)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() int
Execute the update and return the result
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
where(String condition, [List args = const []]) UpdateQuery
Add WHERE condition

Operators

operator ==(Object other) bool
The equality operator.
inherited