IsolateQueue class
Isolate-based queue implementation
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
String queue) → Future< void> -
Clear all jobs from a queue
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop(
String queue) → Future< Job?> -
Pop a job from the queue
override
-
push(
String queue, String payload) → Future< String> -
Push a job to the queue
override
-
size(
String queue) → Future< int> -
Get the number of pending jobs in a queue
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited