Job class

A job to be processed by a queue

Constructors

Job({required String id, required String queue, required String payload, required DateTime createdAt})
Job.fromJson(Map<String, dynamic> json)
Create job from JSON
factory

Properties

createdAt DateTime
final
error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
payload String
final
queue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status JobStatus
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert job to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited