JobHandler class abstract

Abstract job handler interface

Constructors

JobHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
maxRetries int
Maximum number of retry attempts (default: 3)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

backoffDelay(int attempt) Duration
Backoff delay calculation (exponential backoff)
failed(Job job, dynamic error, StackTrace stackTrace) Future<void>
Handle failed job
handle(Job job) Future<void>
Handle the job execution
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited