JobProcessor class

Job processor with retry logic

Constructors

JobProcessor(JobHandler handler, {int? maxRetries})

Properties

handler JobHandler
final
hashCode int
The hash code for this object.
no setterinherited
maxRetries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processWithRetry(Job job) Future<void>
Process a job with retry logic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited