QueueManager class

Queue manager for Dartian

Constructors

QueueManager(Queue _queue, QueueWorker _worker)

Properties

hashCode int
The hash code for this object.
no setterinherited
jobStream Stream<Job>
Stream of jobs being processed
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push(String queue, String payload) Future<String>
Push a job to the queue
size(String queue) Future<int>
Get queue size
start({String? queue}) Future<void>
Start processing jobs
stop() Future<void>
Stop processing jobs
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited