QueueWorker class abstract

Queue worker interface

Constructors

QueueWorker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(Job job) Future<void>
Process a job
start() Future<void>
Start the worker
stop() Future<void>
Stop the worker
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited