Router class

A fluent DSL for building routes

Constructors

Router({String? prefix})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shelfRouter → Router
Get the underlying shelf Router
no setter

Methods

delete(String pattern, Handler handler, {String? name}) Router
Add a DELETE route
get(String pattern, Handler handler, {String? name}) Router
Add a GET route
getRoute(String name) String?
Get a named route pattern
group(String pattern, void callback(Router router)) Router
Create a route group with a common prefix
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String pattern, Handler handler, {String? name}) Router
Add a POST route
put(String pattern, Handler handler, {String? name}) Router
Add a PUT route
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited