ScheduledTask class

Scheduled task

Constructors

ScheduledTask({required String id, required String name, required String cronExpression, required dynamic callback(), required DateTime createdAt})
ScheduledTask.fromJson(Map<String, dynamic> json)
Create task from JSON
factory

Properties

callback → dynamic Function()
final
createdAt DateTime
final
cronExpression String
final
error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
lastRun DateTime?
getter/setter pair
name String
final
nextRun DateTime?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TaskStatus
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert task to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited