View class

View class for rendering mustache templates

Constructors

View({required String templatePath, required Map<String, dynamic> data, String? layout})

Properties

data Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
layout String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templatePath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render() String
Render the view with mustache
toResponse({int status = 200}) → Response
Render and return a Shelf Response
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited