JwtGuard class
JWT-based authentication guard
- Implemented types
Properties
-
exceptRoutes
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jwtSecret → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
check(
Request request) → Future< bool> -
Check if request is authenticated
override
-
middleware(
) → Middleware -
Create guard middleware
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
user(
Request request) → Map< String, dynamic> ? -
Get user data from request
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited