SessionGuard class
Session-based authentication guard
- Implemented types
Constructors
-
SessionGuard({Duration sessionDuration = const Duration(hours: 24), List<
String> exceptRoutes = const [], String sessionCookieName = 'dartian_session'})
Properties
-
exceptRoutes
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionCookieName → String
-
final
- sessionDuration → Duration
-
final
Methods
-
check(
Request request) → Future< bool> -
Check if request is authenticated
override
-
cleanupExpiredSessions(
) → void - Clean up expired sessions (should be called periodically)
-
createSession(
String userId, {Map< String, dynamic> ? data}) → String - Create a new session
-
destroySession(
String sessionId) → void - Destroy a session
-
getSession(
String sessionId) → Session? - Get session by ID
-
middleware(
) → Middleware -
Create guard middleware
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
user(
Request request) → Map< String, dynamic> ? -
Get user data from request
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited