Module class
Marks a class as a module that groups related service registrations Modules help organize large applications by grouping related services
Example:
@Module()
class DatabaseModule {
@Singleton()
DatabaseConnection provideConnection() => DatabaseConnection();
@Service()
UserRepository provideUserRepo(DatabaseConnection conn) =>
UserRepository(conn);
}
Constructors
- Module()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited