HttpKernel class

HTTP Kernel for handling HTTP requests

Constructors

HttpKernel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(Request request) Future<Response>
Handle a request and return a response
listen(String host, int port) Future<HttpServer>
Start the HTTP server
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHandler(Handler handler) → void
Set the request handler
toString() String
A string representation of this object.
inherited
use(Middleware middleware) → void
Add middleware to the pipeline

Operators

operator ==(Object other) bool
The equality operator.
inherited