DartianDatabase class
Base database class for Dartian ORM using Drift
This class provides the foundation for type-safe database operations. To use it, create a subclass that defines your tables.
Example:
@DriftDatabase(tables: [Users, Posts])
class AppDatabase extends DartianDatabase {
AppDatabase(super.config);
@override
int get schemaVersion => 1;
}
- Annotations
-
- @DriftDatabase(tables: [])
Constructors
- DartianDatabase(DatabaseConfig config)
Properties
- config → DatabaseConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
no setter
Methods
-
closeConnection(
) → Future< void> - Close the database connection
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited