MigrationOperations class
Common migration operations helper
Constructors
- MigrationOperations(Migrator migrator, QueryExecutor executor)
Properties
- executor → QueryExecutor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- migrator → Migrator
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addColumn(
String table, String columnDef) → Future< void> - Add a column to a table
-
createIndex(
String indexName, String table, List< String> columns, {bool unique = false}) → Future<void> - Create an index
-
dropColumn(
String table, String column) → Future< void> - Drop a column (SQLite 3.35.0+)
-
dropIndex(
String indexName) → Future< void> - Drop an index
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
raw(
String sql) → Future< void> - Execute raw SQL
-
renameColumn(
String table, String oldName, String newName) → Future< void> - Rename a column (SQLite 3.25.0+)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited