PubSubManager class
Redis Pub/Sub manager
Constructors
- PubSubManager(RedisClient _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ Stream<
PubSubMessage> -
Stream of incoming messages
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> - Close the pub/sub manager
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
String channel, String message) → Future< int> - Publish a message to a channel
-
subscribe(
String channel) → Future< void> - Subscribe to a channel
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
String channel) → Future< void> - Unsubscribe from a channel
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited